@@ -3,11 +3,12 @@
 #' Given an estimated VAR model, this function applies changes in volatility to identify the structural impact matrix B of the corresponding SVAR model
 #' \deqn{y_t=c_t+A_1 y_{t-1}+...+A_p y_{t-p}+u_t
 #' =c_t+A_1 y_{t-1}+...+A_p y_{t-p}+B \epsilon_t.}
-#' Matrix B corresponds to the decomposition of the pre-break covariance matrix \eqn{\Sigma_1=B B'}. The post-break covariance corresponds to \eqn{\Sigma_2=B\Lambda B'} where \eqn{\Lambda} is the estimated unconditional heteroskedasticity matrix.
+#' Matrix B corresponds to the decomposition of the pre-break covariance matrix \eqn{\Sigma_1=B B'}.
+#' The post-break covariance corresponds to \eqn{\Sigma_2=B\Lambda B'} where \eqn{\Lambda} is the estimated unconditional heteroskedasticity matrix.
 #'
 #' @param x An object of class 'vars', 'vec2var', 'nlVar'. Estimated VAR object
-#' @param SB Integer or date character. The structural break is specified either by an integer (number of observations in the pre-break period) or
-#'                    a date character. If a date character is provided, either a date vector containing the whole time line
+#' @param SB Integer, vector or date character. The structural break is specified either by an integer (number of observations in the pre-break period),
+#'                    a vector of ts() frequencies if a ts object is used in the VAR or a date character. If a date character is provided, either a date vector containing the whole time line
 #'                    in the corresponding format (see examples) or common time parameters need to be provided
 #' @param dateVector Vector. Vector of time periods containing SB in corresponding format
 #' @param start Character. Start of the time series (only if dateVector is empty)
@@ -39,13 +40,13 @@
 #' @examples
 #' \donttest{
 #' # data contains quartlery observations from 1965Q1 to 2008Q2
-#' # assumed structural break in 1979Q4
+#' # assumed structural break in 1979Q3
 #' # x = output gap
 #' # pi = inflation
 #' # i = interest rates
 #' set.seed(23211)
 #' v1 <- vars::VAR(USA, lag.max = 10, ic = "AIC" )
-#' x1 <- id.cv(v1, SB = 60)
+#' x1 <- id.cv(v1, SB = 59)
 #' summary(x1)
 #'
 #' # switching columns according to sign patter
@@ -60,16 +61,23 @@
 #' # Assuming that the interest rate doesn't influence the output gap on impact
 #' restMat <- matrix(rep(NA, 9), ncol = 3)
 #' restMat[1,3] <- 0
-#' x2 <- id.cv(v1, SB = 60, restriction_matrix = restMat)
+#' x2 <- id.cv(v1, SB = 59, restriction_matrix = restMat)
+#' summary(x2)
 #'
 #' #Structural brake via Dates
 #' # given that time series vector with dates is available
-#' dateVector = seq(as.Date("1965/1/1"), as.Date("2008/6/1"), "quarter")
-#' x3 <- id.cv(v1, SB = "1985-01-01", format = "%Y-%m-%d", dateVector = dateVector)
+#' dateVector = seq(as.Date("1965/1/1"), as.Date("2008/7/1"), "quarter")
+#' x3 <- id.cv(v1, SB = "1979-07-01", format = "%Y-%m-%d", dateVector = dateVector)
+#' summary(x3)
 #'
 #' # or pass sequence arguments directly
-#' x4 <- id.cv(v1, SB = "1985-01-01", format = "%Y-%m-%d", start = "1965-01-01", end = "2008-06-01",
+#' x4 <- id.cv(v1, SB = "1979-07-01", format = "%Y-%m-%d", start = "1965-01-01", end = "2008-07-01",
 #' frequency = "quarter")
+#' summary(x4)
+#'
+#' # or provide ts date format (For quarterly, monthly, weekly and daily frequencies only)
+#' x5 <- id.cv(v1, SB = c(1979, 3))
+#' summary(x5)
 #'
 #' }
 #' @importFrom steadyICA steadyICA
@@ -134,6 +142,23 @@ id.cv <- function(x, SB, start = NULL, end = NULL, frequency = NULL,
                              frequency = frequency, format = format, dateVector = dateVector, Tob = Tob, p = p)
   }
 
+    if(length(SB) != 1 & inherits(x$y, "ts")){
+      SBts = SB
+      SB = dim(window(x$y, end = SB))[1]
+      if(frequency(x$y == 4)){
+        SBcharacter = paste(SBts[1], " Q", SBts[2], sep = "")
+      }else if(frequency(x$y == 12)){
+        SBcharacter = paste(SBts[1], " M", SBts[2], sep = "")
+      }else if(frequency(x$y == 52)){
+        SBcharacter = paste(SBts[1], " W", SBts[2], sep = "")
+      }else if(frequency(x$y == 365.25)){
+        SBcharacter = paste(SBts[1], "-", SBts[2], "-", SBts[3], sep = "")
+      }else{
+        SBcharacter = NULL
+      }
+
+    }
+
 
   TB <- SB - p
 
@@ -145,10 +170,10 @@ id.cv <- function(x, SB, start = NULL, end = NULL, frequency = NULL,
   if(!is.null(restriction_matrix)){
    resultUnrestricted <- identifyVolatility(x, SB, Tob = Tob, u_t = u_t, k = k, y = y, restriction_matrix = NULL,
                                  Sigma_hat1 = Sigma_hat1, Sigma_hat2 = Sigma_hat2, p = p, TB = TB, SBcharacter,
-                                 max.iter = max.iter)
+                                 max.iter = max.iter, crit = crit)
     result <- identifyVolatility(x, SB, Tob = Tob, u_t = u_t, k = k, y = y, restriction_matrix = restriction_matrix,
                                            Sigma_hat1 = Sigma_hat1, Sigma_hat2 = Sigma_hat2, p = p, TB = TB, SBcharacter,
-                                 max.iter = max.iter)
+                                 max.iter = max.iter, crit = crit)
 
     lRatioTestStatistic = 2 * (resultUnrestricted$Lik - result$Lik)
     pValue = round(1 - pchisq(lRatioTestStatistic, result$restrictions), 4)
@@ -159,7 +184,7 @@ id.cv <- function(x, SB, start = NULL, end = NULL, frequency = NULL,
     restriction_matrix <- NULL
     result <- identifyVolatility(x, SB, Tob = Tob, u_t = u_t, k = k, y = y, restriction_matrix = restriction_matrix,
                                  Sigma_hat1 = Sigma_hat1, Sigma_hat2 = Sigma_hat2, p = p, TB = TB, SBcharacter,
-                                 max.iter = max.iter)
+                                 max.iter = max.iter, crit = crit)
   }
 
   class(result) <- "svars"
