@@ -22,12 +22,17 @@ LH <- function(S, Tob, TB, Sigma_hat1, k,  Sigma_hat2, restriction_matrix, restr
   MMM <- tcrossprod(W)
   MMM2 <- W %*% tcrossprod(Psi, W)
 
+  if(any(Psi < 0) | abs(MW) < 0.01 |  abs(MW2) < 0.01){
+    return(1e25)
+  }
+
+
   #if(MW > 0.5 & MW2 > 0.5){
-    L <- suppressWarnings(-(((TB - 1) / 2) * (log(MW) + sum(diag((Sigma_hat1 %*% solve(MMM)))))) -
-      (((Tob - TB + 1) / 2) * (log(MW2) + sum(diag((Sigma_hat2 %*% solve(MMM2)))))))
+  L <- suppressWarnings(-(((TB - 1) / 2) * (log(MW) + sum(diag((Sigma_hat1 %*% solve(MMM)))))) -
+                          (((Tob - TB + 1) / 2) * (log(MW2) + sum(diag((Sigma_hat2 %*% solve(MMM2)))))))
   return(-L)
- # }else{
+  # }else{
   #  return(NA)
- # }
+  # }
 
 }
